@@ -98,12 +98,12 @@ build_time_vars = {'ABIFLAGS': 'd',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.9d',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.10/build/debug/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.10/build/debug/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.9.13/build/debug/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.9.13/build/debug/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.9.10/Include',
+             '-I/builddir/build/BUILD/Python-3.9.13/Include',
  'CXX': 'g++',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.9 '
              '/usr/lib64/python3.9/lib-dynload',
@@ -328,6 +328,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_LIBUUID': 1,
  'HAVE_LINK': 1,
  'HAVE_LINKAT': 1,
+ 'HAVE_LINUX_AUXVEC_H': 1,
  'HAVE_LINUX_CAN_BCM_H': 1,
  'HAVE_LINUX_CAN_H': 1,
  'HAVE_LINUX_CAN_J1939_H': 1,
@@ -490,6 +491,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
+ 'HAVE_SYS_AUXV_H': 1,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
@@ -621,7 +623,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.10/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.9.13/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -738,9 +740,9 @@ build_time_vars = {'ABIFLAGS': 'd',
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
                              '-fwrapv -fno-semantic-interposition -O0 -Wno-cpp '
-                             '-I/builddir/build/BUILD/Python-3.9.10/Include/internal '
+                             '-I/builddir/build/BUILD/Python-3.9.13/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.9.10/Include '
+                             '-I/builddir/build/BUILD/Python-3.9.13/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
@@ -782,7 +784,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition '
                      '-O0 -Wno-cpp '
-                     '-I/builddir/build/BUILD/Python-3.9.10/Include/internal',
+                     '-I/builddir/build/BUILD/Python-3.9.13/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
                    '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2  -fexceptions -g '
@@ -821,9 +823,9 @@ build_time_vars = {'ABIFLAGS': 'd',
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
                    '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition '
                    '-O0 -Wno-cpp '
-                   '-I/builddir/build/BUILD/Python-3.9.10/Include/internal '
+                   '-I/builddir/build/BUILD/Python-3.9.13/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
-                   '-I/builddir/build/BUILD/Python-3.9.10/Include -fPIC '
+                   '-I/builddir/build/BUILD/Python-3.9.13/Include -fPIC '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  '
                     '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g '
@@ -837,7 +839,7 @@ build_time_vars = {'ABIFLAGS': 'd',
                     '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                     '-fno-semantic-interposition -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.9.10/Include',
+                '-I/builddir/build/BUILD/Python-3.9.13/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now    -g  -Wl,-z,relro '
                '-Wl,--as-needed  -Wl,-z,now    -g',
@@ -894,9 +896,9 @@ build_time_vars = {'ABIFLAGS': 'd',
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-D_GNU_SOURCE -fPIC -fwrapv '
                         '-fno-semantic-interposition -O0 -Wno-cpp '
-                        '-I/builddir/build/BUILD/Python-3.9.10/Include/internal '
+                        '-I/builddir/build/BUILD/Python-3.9.13/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.9.10/Include -fPIC',
+                        '-I/builddir/build/BUILD/Python-3.9.13/Include -fPIC',
  'Py_DEBUG': 1,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -905,7 +907,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.10/build/debug',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.13/build/debug',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -934,7 +936,7 @@ build_time_vars = {'ABIFLAGS': 'd',
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-39d-aarch64-linux-gnu',
  'SRCDIRS': 'Parser Parser/pegen Objects Python Modules Modules/_io Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.10/Tools/gdb/libpython.py',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.9.13/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -946,12 +948,12 @@ build_time_vars = {'ABIFLAGS': 'd',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.10/build/debug '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.13/build/debug '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.10/build/debug '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.9.13/build/debug '
                './python '
-               '/builddir/build/BUILD/Python-3.9.10/Tools/scripts/run_tests.py',
+               '/builddir/build/BUILD/Python-3.9.13/Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
@@ -960,10 +962,10 @@ build_time_vars = {'ABIFLAGS': 'd',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.9 '
-                '/builddir/build/BUILD/Python-3.9.10/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.9.13/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.9',
- 'VPATH': '/builddir/build/BUILD/Python-3.9.10',
+ 'VPATH': '/builddir/build/BUILD/Python-3.9.13',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DECIMAL_CONTEXTVAR': 1,
  'WITH_DOC_STRINGS': 1,
@@ -975,9 +977,9 @@ build_time_vars = {'ABIFLAGS': 'd',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.9.10/build/debug',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.10',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.9.13/build/debug',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.9.13',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.9.10'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.9.13'}
